@@ -4,7 +4,7 @@
 //!
 //! * GitHub Actions (with `id-token: write`)
 //! * GitLab CI
-//! * BuildKite
+//! * Buildkite
 //!
 //! # Usage
 //!
@@ -25,10 +25,11 @@ use reqwest_middleware::ClientWithMiddleware;
 use secrecy::{ExposeSecret, SecretString};
 
 mod buildkite;
+mod circleci;
 mod github;
 mod gitlab;
 
-pub use buildkite::Error as BuildKiteError;
+pub use buildkite::Error as BuildkiteError;
 pub use github::Error as GitHubError;
 pub use gitlab::Error as GitLabError;
 
@@ -59,9 +60,12 @@ pub enum Error {
     /// An error occurred while detecting GitLab CI credentials.
     #[error("GitLab CI detection error")]
     GitLabCI(#[from] GitLabError),
-    /// An error occurred while detecting BuildKite credentials.
-    #[error("BuildKite detection error")]
-    BuildKite(#[from] buildkite::Error),
+    /// An error occurred while detecting Buildkite credentials.
+    #[error("Buildkite detection error")]
+    Buildkite(#[from] buildkite::Error),
+    /// An error occurred while detecting CircleCI credentials.
+    #[error("CircleCI detection error")]
+    CircleCI(#[from] circleci::Error),
 }
 
 #[derive(Default)]
@@ -132,7 +136,8 @@ impl Detector {
         detect!(
             github::GitHubActions,
             gitlab::GitLabCI,
-            buildkite::BuildKite
+            buildkite::Buildkite,
+            circleci::CircleCI
         )
     }
 }
@@ -208,6 +213,7 @@ mod tests {
         scope.unsetenv("GITHUB_ACTIONS");
         scope.unsetenv("GITLAB_CI");
         scope.unsetenv("BUILDKITE");
+        scope.unsetenv("CIRCLECI");
 
         let detector = Detector::new();
 
