@@ -1,12 +1,20 @@
+// Copyright 2018 the Kurbo Authors
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
 //! SVG path representation.
 
-use std::error::Error;
-use std::f64::consts::PI;
-use std::fmt::{self, Display, Formatter};
+use alloc::vec::Vec;
+use core::error::Error;
+use core::f64::consts::PI;
+use core::fmt::{self, Display, Formatter};
+#[cfg(feature = "std")]
 use std::io::{self, Write};
 
 use crate::{Arc, BezPath, ParamCurve, PathEl, PathSeg, Point, Vec2};
 
+#[cfg(not(feature = "std"))]
+use crate::common::FloatFuncs;
+
 // Note: the SVG arc logic is heavily adapted from https://github.com/nical/lyon
 
 /// A single SVG arc segment.
@@ -30,7 +38,7 @@ pub struct SvgArc {
 }
 
 impl BezPath {
-    /// Create a BezPath with segments corresponding to the sequence of
+    /// Create a `BezPath` with segments corresponding to the sequence of
     /// `PathSeg`s
     pub fn from_path_segments(segments: impl Iterator<Item = PathSeg>) -> BezPath {
         let mut path_elements = Vec::new();
@@ -40,7 +48,7 @@ impl BezPath {
             let start = segment.start();
             if Some(start) != current_pos {
                 path_elements.push(PathEl::MoveTo(start));
-            };
+            }
             path_elements.push(match segment {
                 PathSeg::Line(l) => PathEl::LineTo(l.p1),
                 PathSeg::Quad(q) => PathEl::QuadTo(q.p1, q.p2),
@@ -57,6 +65,7 @@ impl BezPath {
     ///
     /// The current implementation doesn't take any special care to produce a
     /// short string (reducing precision, using relative movement).
+    #[cfg(feature = "std")]
     pub fn to_svg(&self) -> String {
         let mut buffer = Vec::new();
         self.write_to(&mut buffer).unwrap();
@@ -64,15 +73,19 @@ impl BezPath {
     }
 
     /// Write the SVG representation of this path to the provided buffer.
+    #[cfg(feature = "std")]
     pub fn write_to<W: Write>(&self, mut writer: W) -> io::Result<()> {
-        for el in self.elements() {
+        for (i, el) in self.elements().iter().enumerate() {
+            if i > 0 {
+                write!(writer, " ")?;
+            }
             match *el {
-                PathEl::MoveTo(p) => write!(writer, "M{} {}", p.x, p.y)?,
-                PathEl::LineTo(p) => write!(writer, "L{} {}", p.x, p.y)?,
-                PathEl::QuadTo(p1, p2) => write!(writer, "Q{} {} {} {}", p1.x, p1.y, p2.x, p2.y)?,
+                PathEl::MoveTo(p) => write!(writer, "M{},{}", p.x, p.y)?,
+                PathEl::LineTo(p) => write!(writer, "L{},{}", p.x, p.y)?,
+                PathEl::QuadTo(p1, p2) => write!(writer, "Q{},{} {},{}", p1.x, p1.y, p2.x, p2.y)?,
                 PathEl::CurveTo(p1, p2, p3) => write!(
                     writer,
-                    "C{} {} {} {} {} {}",
+                    "C{},{} {},{} {},{}",
                     p1.x, p1.y, p2.x, p2.y, p3.x, p3.y
                 )?,
                 PathEl::ClosePath => write!(writer, "Z")?,
@@ -96,6 +109,10 @@ impl BezPath {
         let mut implicit_moveto = None;
         while let Some(c) = lexer.get_cmd(last_cmd) {
             if c != b'm' && c != b'M' {
+                if path.elements().is_empty() {
+                    return Err(SvgParseError::UninitializedPath);
+                }
+
                 if let Some(pt) = implicit_moveto.take() {
                     path.move_to(pt);
                 }
@@ -229,6 +246,7 @@ impl BezPath {
 
 /// An error which can be returned when parsing an SVG.
 #[derive(Debug)]
+#[non_exhaustive]
 pub enum SvgParseError {
     /// A number was expected.
     Wrong,
@@ -236,6 +254,8 @@ pub enum SvgParseError {
     UnexpectedEof,
     /// Encountered an unknown command letter.
     UnknownCommand(char),
+    /// Encountered a command that precedes expected 'moveto' command.
+    UninitializedPath,
 }
 
 impl Display for SvgParseError {
@@ -243,7 +263,10 @@ impl Display for SvgParseError {
         match self {
             SvgParseError::Wrong => write!(f, "Unable to parse a number"),
             SvgParseError::UnexpectedEof => write!(f, "Unexpected EOF"),
-            SvgParseError::UnknownCommand(letter) => write!(f, "Unknown command, \"{}\"", letter),
+            SvgParseError::UnknownCommand(letter) => write!(f, "Unknown command, \"{letter}\""),
+            SvgParseError::UninitializedPath => {
+                write!(f, "Uninitialized path (missing moveto command)")
+            }
         }
     }
 }
@@ -256,8 +279,8 @@ struct SvgLexer<'a> {
     pub last_pt: Point,
 }
 
-impl<'a> SvgLexer<'a> {
-    fn new(data: &str) -> SvgLexer {
+impl SvgLexer<'_> {
+    fn new(data: &str) -> SvgLexer<'_> {
         SvgLexer {
             data,
             ix: 0,
@@ -277,9 +300,9 @@ impl<'a> SvgLexer<'a> {
     fn get_cmd(&mut self, last_cmd: u8) -> Option<u8> {
         self.skip_ws();
         if let Some(c) = self.get_byte() {
-            if (b'a'..=b'z').contains(&c) || (b'A'..=b'Z').contains(&c) {
+            if c.is_ascii_lowercase() || c.is_ascii_uppercase() {
                 return Some(c);
-            } else if last_cmd != 0 && (c == b'-' || c == b'.' || (b'0'..=b'9').contains(&c)) {
+            } else if last_cmd != 0 && (c == b'-' || c == b'.' || c.is_ascii_digit()) {
                 // Plausible number start
                 self.unget();
                 return Some(last_cmd);
@@ -311,7 +334,7 @@ impl<'a> SvgLexer<'a> {
         let mut digit_count = 0;
         let mut seen_period = false;
         while let Some(c) = self.get_byte() {
-            if (b'0'..=b'9').contains(&c) {
+            if c.is_ascii_digit() {
                 digit_count += 1;
             } else if c == b'.' && !seen_period {
                 seen_period = true;
@@ -324,13 +347,13 @@ impl<'a> SvgLexer<'a> {
             if c == b'e' || c == b'E' {
                 let mut c = self.get_byte().ok_or(SvgParseError::Wrong)?;
                 if c == b'-' || c == b'+' {
-                    c = self.get_byte().ok_or(SvgParseError::Wrong)?
+                    c = self.get_byte().ok_or(SvgParseError::Wrong)?;
                 }
-                if !(b'0'..=b'9').contains(&c) {
+                if !c.is_ascii_digit() {
                     return Err(SvgParseError::Wrong);
                 }
                 while let Some(c) = self.get_byte() {
-                    if !(b'0'..=b'9').contains(&c) {
+                    if !c.is_ascii_digit() {
                         self.unget();
                         break;
                     }
@@ -367,7 +390,7 @@ impl<'a> SvgLexer<'a> {
 
     fn get_maybe_relative(&mut self, cmd: u8) -> Result<Point, SvgParseError> {
         let pt = self.get_number_pair()?;
-        if (b'a'..=b'z').contains(&cmd) {
+        if cmd.is_ascii_lowercase() {
             Ok(self.last_pt + pt.to_vec2())
         } else {
             Ok(pt)
@@ -387,7 +410,7 @@ impl<'a> SvgLexer<'a> {
 impl SvgArc {
     /// Checks that arc is actually a straight line.
     ///
-    /// In this case, it can be replaced with a LineTo.
+    /// In this case, it can be replaced with a `LineTo`.
     pub fn is_straight_line(&self) -> bool {
         self.radii.x.abs() <= 1e-5 || self.radii.y.abs() <= 1e-5 || self.from == self.to
     }
@@ -407,8 +430,7 @@ impl Arc {
         let mut ry = arc.radii.y.abs();
 
         let xr = arc.x_rotation % (2.0 * PI);
-        let cos_phi = xr.cos();
-        let sin_phi = xr.sin();
+        let (sin_phi, cos_phi) = xr.sin_cos();
         let hd_x = (arc.from.x - arc.to.x) * 0.5;
         let hd_y = (arc.from.y - arc.to.y) * 0.5;
         let hs_x = (arc.from.x + arc.to.x) * 0.5;
@@ -481,7 +503,7 @@ impl Arc {
 
 #[cfg(test)]
 mod tests {
-    use crate::{BezPath, CubicBez, Line, ParamCurve, PathSeg, Point, QuadBez, Shape};
+    use crate::{BezPath, CubicBez, Line, ParamCurve, PathEl, PathSeg, Point, QuadBez, Shape};
 
     #[test]
     fn test_parse_svg() {
@@ -512,6 +534,28 @@ mod tests {
         assert_eq!(path.perimeter(1e-6).round(), 168.0);
     }
 
+    #[test]
+    fn test_parse_svg_uninitialized() {
+        let path = BezPath::from_svg("L10 10 100 0 0 100");
+        assert!(path.is_err());
+    }
+
+    #[test]
+    #[allow(clippy::float_cmp)]
+    fn test_parse_scientific_notation() {
+        let path = BezPath::from_svg("M 0 0 L 1e-123 -4E+5").unwrap();
+        assert_eq!(
+            path.elements(),
+            &[
+                PathEl::MoveTo(Point { x: 0.0, y: 0.0 }),
+                PathEl::LineTo(Point {
+                    x: 1e-123,
+                    y: -4E+5
+                })
+            ]
+        );
+    }
+
     #[test]
     fn test_write_svg_single() {
         let segments = [CubicBez::new(
@@ -523,7 +567,7 @@ mod tests {
         .into()];
         let path = BezPath::from_path_segments(segments.iter().cloned());
 
-        assert_eq!(path.to_svg(), "M10 10C20 20 30 30 40 40");
+        assert_eq!(path.to_svg(), "M10,10 C20,20 30,30 40,40");
     }
 
     #[test]
@@ -546,7 +590,10 @@ mod tests {
         ];
         let path = BezPath::from_path_segments(segments.iter().cloned());
 
-        assert_eq!(path.to_svg(), "M10 10C20 20 30 30 40 40C30 30 20 20 10 10");
+        assert_eq!(
+            path.to_svg(),
+            "M10,10 C20,20 30,30 40,40 C30,30 20,20 10,10"
+        );
     }
 
     #[test]
@@ -571,11 +618,18 @@ mod tests {
 
         assert_eq!(
             path.to_svg(),
-            "M10 10C20 20 30 30 40 40M50 50C30 30 20 20 10 10"
+            "M10,10 C20,20 30,30 40,40 M50,50 C30,30 20,20 10,10"
         );
     }
 
     use rand::prelude::*;
+    // Suppress the unused_crate_dependencies lint for getrandom.
+    #[cfg(all(
+        target_arch = "wasm32",
+        target_vendor = "unknown",
+        target_os = "unknown"
+    ))]
+    use getrandom as _;
 
     fn gen_random_path_sequence(rng: &mut impl Rng) -> Vec<PathSeg> {
         const MAX_LENGTH: u32 = 10;
@@ -583,30 +637,30 @@ mod tests {
         let mut elements = vec![];
         let mut position = None;
 
-        let length = rng.gen_range(0..MAX_LENGTH);
+        let length = rng.random_range(0..MAX_LENGTH);
         for _ in 0..length {
-            let should_follow: bool = rand::random();
-            let kind = rng.gen_range(0..3);
+            let should_follow: bool = rand::random_bool(0.5);
+            let kind = rng.random_range(0..3);
 
             let first = position
                 .filter(|_| should_follow)
-                .unwrap_or_else(|| Point::new(rng.gen(), rng.gen()));
+                .unwrap_or_else(|| Point::new(rng.random(), rng.random()));
 
             let element: PathSeg = match kind {
-                0 => Line::new(first, Point::new(rng.gen(), rng.gen())).into(),
+                0 => Line::new(first, Point::new(rng.random(), rng.random())).into(),
 
                 1 => QuadBez::new(
                     first,
-                    Point::new(rng.gen(), rng.gen()),
-                    Point::new(rng.gen(), rng.gen()),
+                    Point::new(rng.random(), rng.random()),
+                    Point::new(rng.random(), rng.random()),
                 )
                 .into(),
 
                 2 => CubicBez::new(
                     first,
-                    Point::new(rng.gen(), rng.gen()),
-                    Point::new(rng.gen(), rng.gen()),
-                    Point::new(rng.gen(), rng.gen()),
+                    Point::new(rng.random(), rng.random()),
+                    Point::new(rng.random(), rng.random()),
+                    Point::new(rng.random(), rng.random()),
                 )
                 .into(),
 
@@ -623,7 +677,7 @@ mod tests {
     #[test]
     fn test_serialize_deserialize() {
         const N_TESTS: u32 = 100;
-        let mut rng = rand::thread_rng();
+        let mut rng = rand::rng();
 
         for _ in 0..N_TESTS {
             let vec = gen_random_path_sequence(&mut rng);
